package com.yijia.system.mapper;

import java.util.List;
import com.yijia.system.domain.SysAgent;

/**
 * 代理机构Mapper接口
 *
 * @author yijia
 * @date 2021-07-01
 */
public interface SysAgentMapper
{
    /**
     * 查询代理机构
     *
     * @param id 代理机构ID
     * @return 代理机构
     */
    public SysAgent selectSysAgentById(Integer id);

    /**
     * 查询代理机构列表
     *
     * @param sysAgent 代理机构
     * @return 代理机构集合
     */
    public List<SysAgent> selectSysAgentList(SysAgent sysAgent);

    /**
     * 新增代理机构
     *
     * @param sysAgent 代理机构
     * @return 结果
     */
    public int insertSysAgent(SysAgent sysAgent);

    /**
     * 修改代理机构
     *
     * @param sysAgent 代理机构
     * @return 结果
     */
    public int updateSysAgent(SysAgent sysAgent);

    /**
     * 删除代理机构
     *
     * @param id 代理机构ID
     * @return 结果
     */
    public int deleteSysAgentById(Integer id);

    /**
     * 批量删除代理机构
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteSysAgentByIds(Integer[] ids);

    public SysAgent selectSysAgent(SysAgent agent);
    /**
     * 批量删除代理机构
     * @param  sysAgent
     * @return 结果
     */
    public int deleteSysAgent(SysAgent sysAgent);
}
